ta

package
v0.0.6-0...-417b642 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 22, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the ta type in the database.
	Label = "ta"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldPublicKey holds the string denoting the public_key field in the database.
	FieldPublicKey = "public_key"
	// FieldIsActive holds the string denoting the is_active field in the database.
	FieldIsActive = "is_active"
	// EdgeCtLog holds the string denoting the ct_log edge name in mutations.
	EdgeCtLog = "ct_log"
	// EdgeEvidenceLog holds the string denoting the evidence_log edge name in mutations.
	EdgeEvidenceLog = "evidence_log"
	// Table holds the table name of the ta in the database.
	Table = "tas"
	// CtLogTable is the table that holds the ct_log relation/edge.
	CtLogTable = "ct_logs"
	// CtLogInverseTable is the table name for the CTLog entity.
	// It exists in this package in order to avoid circular dependency with the "ctlog" package.
	CtLogInverseTable = "ct_logs"
	// CtLogColumn is the table column denoting the ct_log relation/edge.
	CtLogColumn = "ct_log_ta"
	// EvidenceLogTable is the table that holds the evidence_log relation/edge.
	EvidenceLogTable = "tas"
	// EvidenceLogInverseTable is the table name for the EvidenceLog entity.
	// It exists in this package in order to avoid circular dependency with the "evidencelog" package.
	EvidenceLogInverseTable = "evidence_logs"
	// EvidenceLogColumn is the table column denoting the evidence_log relation/edge.
	EvidenceLogColumn = "evidence_log_ta"
)

Variables

Columns holds all SQL columns for ta fields.

var (
	// DefaultIsActive holds the default value on creation for the "is_active" field.
	DefaultIsActive bool
)
var ForeignKeys = []string{
	"evidence_log_ta",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "tas" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.TA) predicate.TA

And groups predicates with the AND operator between them.

func HasCtLog

func HasCtLog() predicate.TA

HasCtLog applies the HasEdge predicate on the "ct_log" edge.

func HasCtLogWith

func HasCtLogWith(preds ...predicate.CTLog) predicate.TA

HasCtLogWith applies the HasEdge predicate on the "ct_log" edge with a given conditions (other predicates).

func HasEvidenceLog

func HasEvidenceLog() predicate.TA

HasEvidenceLog applies the HasEdge predicate on the "evidence_log" edge.

func HasEvidenceLogWith

func HasEvidenceLogWith(preds ...predicate.EvidenceLog) predicate.TA

HasEvidenceLogWith applies the HasEdge predicate on the "evidence_log" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.TA

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.TA

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.TA

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.TA

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.TA

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.TA

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.TA

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.TA

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.TA

IDNotIn applies the NotIn predicate on the ID field.

func IsActive

func IsActive(v bool) predicate.TA

IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.

func IsActiveEQ

func IsActiveEQ(v bool) predicate.TA

IsActiveEQ applies the EQ predicate on the "is_active" field.

func IsActiveNEQ

func IsActiveNEQ(v bool) predicate.TA

IsActiveNEQ applies the NEQ predicate on the "is_active" field.

func Not

func Not(p predicate.TA) predicate.TA

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.TA) predicate.TA

Or groups predicates with the OR operator between them.

func PublicKey

func PublicKey(v []byte) predicate.TA

PublicKey applies equality check predicate on the "public_key" field. It's identical to PublicKeyEQ.

func PublicKeyEQ

func PublicKeyEQ(v []byte) predicate.TA

PublicKeyEQ applies the EQ predicate on the "public_key" field.

func PublicKeyGT

func PublicKeyGT(v []byte) predicate.TA

PublicKeyGT applies the GT predicate on the "public_key" field.

func PublicKeyGTE

func PublicKeyGTE(v []byte) predicate.TA

PublicKeyGTE applies the GTE predicate on the "public_key" field.

func PublicKeyIn

func PublicKeyIn(vs ...[]byte) predicate.TA

PublicKeyIn applies the In predicate on the "public_key" field.

func PublicKeyLT

func PublicKeyLT(v []byte) predicate.TA

PublicKeyLT applies the LT predicate on the "public_key" field.

func PublicKeyLTE

func PublicKeyLTE(v []byte) predicate.TA

PublicKeyLTE applies the LTE predicate on the "public_key" field.

func PublicKeyNEQ

func PublicKeyNEQ(v []byte) predicate.TA

PublicKeyNEQ applies the NEQ predicate on the "public_key" field.

func PublicKeyNotIn

func PublicKeyNotIn(vs ...[]byte) predicate.TA

PublicKeyNotIn applies the NotIn predicate on the "public_key" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the TA queries.

func ByCtLog

func ByCtLog(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByCtLog orders the results by ct_log terms.

func ByCtLogCount

func ByCtLogCount(opts ...sql.OrderTermOption) OrderOption

ByCtLogCount orders the results by ct_log count.

func ByEvidenceLogField

func ByEvidenceLogField(field string, opts ...sql.OrderTermOption) OrderOption

ByEvidenceLogField orders the results by evidence_log field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIsActive

func ByIsActive(opts ...sql.OrderTermOption) OrderOption

ByIsActive orders the results by the is_active field.

Jump to