Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.TA) predicate.TA
- func HasCtLog() predicate.TA
- func HasCtLogWith(preds ...predicate.CTLog) predicate.TA
- func HasEvidenceLog() predicate.TA
- func HasEvidenceLogWith(preds ...predicate.EvidenceLog) predicate.TA
- func ID(id int) predicate.TA
- func IDEQ(id int) predicate.TA
- func IDGT(id int) predicate.TA
- func IDGTE(id int) predicate.TA
- func IDIn(ids ...int) predicate.TA
- func IDLT(id int) predicate.TA
- func IDLTE(id int) predicate.TA
- func IDNEQ(id int) predicate.TA
- func IDNotIn(ids ...int) predicate.TA
- func IsActive(v bool) predicate.TA
- func IsActiveEQ(v bool) predicate.TA
- func IsActiveNEQ(v bool) predicate.TA
- func Not(p predicate.TA) predicate.TA
- func Or(predicates ...predicate.TA) predicate.TA
- func PublicKey(v []byte) predicate.TA
- func PublicKeyEQ(v []byte) predicate.TA
- func PublicKeyGT(v []byte) predicate.TA
- func PublicKeyGTE(v []byte) predicate.TA
- func PublicKeyIn(vs ...[]byte) predicate.TA
- func PublicKeyLT(v []byte) predicate.TA
- func PublicKeyLTE(v []byte) predicate.TA
- func PublicKeyNEQ(v []byte) predicate.TA
- func PublicKeyNotIn(vs ...[]byte) predicate.TA
- func ValidColumn(column string) bool
- type OrderOption
- func ByCtLog(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByCtLogCount(opts ...sql.OrderTermOption) OrderOption
- func ByEvidenceLogField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIsActive(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the ta type in the database. Label = "ta" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldPublicKey holds the string denoting the public_key field in the database. FieldPublicKey = "public_key" // FieldIsActive holds the string denoting the is_active field in the database. FieldIsActive = "is_active" // EdgeCtLog holds the string denoting the ct_log edge name in mutations. EdgeCtLog = "ct_log" // EdgeEvidenceLog holds the string denoting the evidence_log edge name in mutations. EdgeEvidenceLog = "evidence_log" // Table holds the table name of the ta in the database. Table = "tas" // CtLogTable is the table that holds the ct_log relation/edge. CtLogTable = "ct_logs" // CtLogInverseTable is the table name for the CTLog entity. // It exists in this package in order to avoid circular dependency with the "ctlog" package. CtLogInverseTable = "ct_logs" // CtLogColumn is the table column denoting the ct_log relation/edge. CtLogColumn = "ct_log_ta" // EvidenceLogTable is the table that holds the evidence_log relation/edge. EvidenceLogTable = "tas" // EvidenceLogInverseTable is the table name for the EvidenceLog entity. // It exists in this package in order to avoid circular dependency with the "evidencelog" package. EvidenceLogInverseTable = "evidence_logs" // EvidenceLogColumn is the table column denoting the evidence_log relation/edge. EvidenceLogColumn = "evidence_log_ta" )
Variables ¶
var Columns = []string{ FieldID, FieldPublicKey, FieldIsActive, }
Columns holds all SQL columns for ta fields.
var ( // DefaultIsActive holds the default value on creation for the "is_active" field. DefaultIsActive bool )
var ForeignKeys = []string{
"evidence_log_ta",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "tas" table and are not defined as standalone fields in the schema.
Functions ¶
func HasCtLogWith ¶
HasCtLogWith applies the HasEdge predicate on the "ct_log" edge with a given conditions (other predicates).
func HasEvidenceLog ¶
HasEvidenceLog applies the HasEdge predicate on the "evidence_log" edge.
func HasEvidenceLogWith ¶
func HasEvidenceLogWith(preds ...predicate.EvidenceLog) predicate.TA
HasEvidenceLogWith applies the HasEdge predicate on the "evidence_log" edge with a given conditions (other predicates).
func IsActive ¶
IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.
func IsActiveEQ ¶
IsActiveEQ applies the EQ predicate on the "is_active" field.
func IsActiveNEQ ¶
IsActiveNEQ applies the NEQ predicate on the "is_active" field.
func PublicKey ¶
PublicKey applies equality check predicate on the "public_key" field. It's identical to PublicKeyEQ.
func PublicKeyEQ ¶
PublicKeyEQ applies the EQ predicate on the "public_key" field.
func PublicKeyGT ¶
PublicKeyGT applies the GT predicate on the "public_key" field.
func PublicKeyGTE ¶
PublicKeyGTE applies the GTE predicate on the "public_key" field.
func PublicKeyIn ¶
PublicKeyIn applies the In predicate on the "public_key" field.
func PublicKeyLT ¶
PublicKeyLT applies the LT predicate on the "public_key" field.
func PublicKeyLTE ¶
PublicKeyLTE applies the LTE predicate on the "public_key" field.
func PublicKeyNEQ ¶
PublicKeyNEQ applies the NEQ predicate on the "public_key" field.
func PublicKeyNotIn ¶
PublicKeyNotIn applies the NotIn predicate on the "public_key" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the TA queries.
func ByCtLog ¶
func ByCtLog(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByCtLog orders the results by ct_log terms.
func ByCtLogCount ¶
func ByCtLogCount(opts ...sql.OrderTermOption) OrderOption
ByCtLogCount orders the results by ct_log count.
func ByEvidenceLogField ¶
func ByEvidenceLogField(field string, opts ...sql.OrderTermOption) OrderOption
ByEvidenceLogField orders the results by evidence_log field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIsActive ¶
func ByIsActive(opts ...sql.OrderTermOption) OrderOption
ByIsActive orders the results by the is_active field.